# Generated by roxygen2: do not edit by hand

export("%>%")
export(.removeSpatialDataDir)
export(CONUS)
export(US_52)
export(US_countyFIPSToName)
export(US_countyNameToFIPS)
export(US_stateCodeToFIPS)
export(US_stateCodeToName)
export(US_stateCodes)
export(US_stateFIPSToCode)
export(US_stateFIPSToName)
export(US_stateNameToCode)
export(US_stateNameToFIPS)
export(codeToCountry)
export(codeToState)
export(convertEEZCountries)
export(convertEPARegions)
export(convertGACC)
export(convertLayer)
export(convertNaturalEarthAdm1)
export(convertOSMTimezones)
export(convertTMWorldBorders)
export(convertUSCensusCBSA)
export(convertUSCensusCongress)
export(convertUSCensusCounties)
export(convertUSCensusStates)
export(convertWBDHUC)
export(convertWeatherZones)
export(convertWikipediaTimezoneTable)
export(countryCodeToFIPS)
export(countryCodeToName)
export(countryFIPSToCode)
export(countryFIPSToName)
export(countryNameToCode)
export(countryNameToFIPS)
export(countryToCode)
export(dissolve)
export(getCountry)
export(getCountryCode)
export(getCountryName)
export(getHUC)
export(getHUCName)
export(getPolygonID)
export(getSpatialData)
export(getSpatialDataDir)
export(getState)
export(getStateCode)
export(getStateName)
export(getTimezone)
export(getUSCounty)
export(getVariable)
export(installSpatialData)
export(installedSpatialData)
export(iso2ToIso3)
export(iso3ToIso2)
export(loadSpatialData)
export(setSpatialDataDir)
export(simplify)
export(simplifyAndSave)
export(stateToCode)
export(summarizeByPolygon)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(sf,st_as_sf)
importFrom(sf,st_intersects)
importFrom(sf,st_is_within_distance)
importFrom(sf,st_set_crs)
